@@ -4,13 +4,16 @@
 import logging
 
 from flask import Flask, request
+from werkzeug.middleware.proxy_fix import ProxyFix
 from configargparse import ArgParser, ArgumentError, Action
 from artifactory import ArtifactoryPath
 
+from .utilities import DateTimeIsoFormatJSONProvider
+
 from .api import bp as api
 from .download import bp as download
 from .health import bp as health
-from .utilities import DateTimeIsoFormatJSONProvider
+from .root import bp as root
 
 
 def create_app(**config):
@@ -18,6 +21,7 @@ def create_app(**config):
     app.json = DateTimeIsoFormatJSONProvider(app)
     app.config.update(**config)
     app.register_blueprint(health)
+    app.register_blueprint(root)
     app.register_blueprint(api)
     app.register_blueprint(download)
 
@@ -52,7 +56,7 @@ class _StrBool(Action):
         setattr(namespace, self.dest, self._booler(values))
 
 
-def create_configured_app(run=False, parse_known_only=True, parse_allow_abbrev=False):
+def create_configured_app(run=False, parse_known_only=True, parse_allow_abbrev=False, proxy_fix=False, **extra):
     parser = ArgParser(
         prog='python -m galactory',
         description=(
@@ -116,6 +120,10 @@ def create_configured_app(run=False, parse_known_only=True, parse_allow_abbrev=F
         HEALTH_CHECK_CUSTOM_TEXT=args.health_check_custom_text,
     )
 
+    if proxy_fix:
+        proxy_args = {k: v for k, v in extra.items() if k.startswith('x_')}
+        app = ProxyFix(app, **proxy_args)
+
     if run:
         app.run(args.listen_addr, args.listen_port, threaded=True)
 
